==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Plot/resources/translations/Plot.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>Plot</name>
    <message>
        <location filename="InitGui.py" line="36"/>
        <source>Plot edition tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="InitGui.py" line="37"/>
        <source>Plot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Axes</name>
    <message>
        <location filename="PlotGui.py" line="67"/>
        <source>Configure axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="68"/>
        <source>Configure axes parameters</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Grid</name>
    <message>
        <location filename="PlotGui.py" line="98"/>
        <source>Show/Hide grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="99"/>
        <source>Show/Hide grid on selected plot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Labels</name>
    <message>
        <location filename="PlotGui.py" line="129"/>
        <source>Set labels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="130"/>
        <source>Set title and axes labels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Legend</name>
    <message>
        <location filename="PlotGui.py" line="117"/>
        <source>Show/Hide legend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="118"/>
        <source>Show/Hide legend on selected plot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Positions</name>
    <message>
        <location filename="PlotGui.py" line="141"/>
        <source>Set positions and sizes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="142"/>
        <source>Set labels and legend positions and sizes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_SaveFig</name>
    <message>
        <location filename="PlotGui.py" line="55"/>
        <source>Save plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="56"/>
        <source>Save plot as image file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Series</name>
    <message>
        <location filename="PlotGui.py" line="79"/>
        <source>Configure series</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="80"/>
        <source>Configure series drawing style and label</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_axes</name>
    <message>
        <location filename="TaskPanel.py" line="130"/>
        <source>Configure axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="132"/>
        <source>Active axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="148"/>
        <source>Apply to all axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="150"/>
        <source>Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="152"/>
        <source>X axis position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="154"/>
        <source>Y axis position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="142"/>
        <source>Scales</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="144"/>
        <source>X auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="146"/>
        <source>Y auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="156"/>
        <source>Index of the active axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="158"/>
        <source>Add new axes to the plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="160"/>
        <source>Remove selected axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="162"/>
        <source>Check it to apply transformations to all axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="164"/>
        <source>Left bound of axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="166"/>
        <source>Right bound of axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="168"/>
        <source>Bottom bound of axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="170"/>
        <source>Top bound of axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="172"/>
        <source>Outward offset of X axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="174"/>
        <source>Outward offset of Y axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="176"/>
        <source>X axis scale autoselection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="178"/>
        <source>Y axis scale autoselection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_console</name>
    <message>
        <location filename="Plot.py" line="38"/>
        <source>matplotlib not found, so Plot module can not be loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="InitGui.py" line="44"/>
        <source>matplotlib not found, Plot module will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="41"/>
        <source>Plot document must be selected in order to save it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="218"/>
        <source>Axes 0 can not be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="88"/>
        <source>Grid must be activated on top of a plot document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="107"/>
        <source>Legend must be activated on top of a plot document</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_labels</name>
    <message>
        <location filename="TaskPanel.py" line="109"/>
        <source>Set labels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="111"/>
        <source>Active axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="113"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="115"/>
        <source>X label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="117"/>
        <source>Y label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="119"/>
        <source>Index of the active axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="121"/>
        <source>Title (associated to active axes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="123"/>
        <source>Title font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="125"/>
        <source>X axis title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="127"/>
        <source>X axis title font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="129"/>
        <source>Y axis title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="131"/>
        <source>Y axis title font size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_positions</name>
    <message>
        <location filename="TaskPanel.py" line="100"/>
        <source>Set positions and sizes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="102"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="104"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="106"/>
        <source>List of modificable items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="108"/>
        <source>X item position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="110"/>
        <source>Y item position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="112"/>
        <source>Item size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_save</name>
    <message>
        <location filename="TaskPanel.py" line="106"/>
        <source>Save figure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="108"/>
        <source>Inches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="110"/>
        <source>Dots per Inch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="112"/>
        <source>Output image file path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="114"/>
        <source>Show a file selection dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="116"/>
        <source>X image size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="118"/>
        <source>Y image size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="120"/>
        <source>Dots per point, with size will define output image resolution</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_series</name>
    <message>
        <location filename="TaskPanel.py" line="115"/>
        <source>No label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="117"/>
        <source>Remove serie</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="129"/>
        <source>Line style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="121"/>
        <source>Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="113"/>
        <source>Configure series</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="123"/>
        <source>List of available series</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="125"/>
        <source>Line title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="131"/>
        <source>Marker style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="133"/>
        <source>Line width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="135"/>
        <source>Marker size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="137"/>
        <source>Line and marker color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="139"/>
        <source>Removes this serie</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="127"/>
        <source>If checked serie will not be considered for legend</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freecad_0.15.4671+dfsg1.orig.tar.xz: freecad-0.15.4671/src/Mod/Plot/resources/translations/Plot.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>Plot</name>
    <message>
        <location filename="InitGui.py" line="44"/>
        <source>Plot edition tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="InitGui.py" line="47"/>
        <source>Plot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Axes</name>
    <message>
        <location filename="PlotGui.py" line="62"/>
        <source>Configure axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="65"/>
        <source>Configure the axes parameters</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Grid</name>
    <message>
        <location filename="PlotGui.py" line="110"/>
        <source>Show/Hide grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="113"/>
        <source>Show/Hide grid on selected plot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Labels</name>
    <message>
        <location filename="PlotGui.py" line="154"/>
        <source>Set labels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="157"/>
        <source>Set title and axes labels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Legend</name>
    <message>
        <location filename="PlotGui.py" line="137"/>
        <source>Show/Hide legend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="140"/>
        <source>Show/Hide legend on selected plot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Positions</name>
    <message>
        <location filename="PlotGui.py" line="171"/>
        <source>Set positions and sizes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="174"/>
        <source>Set labels and legend positions and sizes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_SaveFig</name>
    <message>
        <location filename="PlotGui.py" line="45"/>
        <source>Save plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="48"/>
        <source>Save the plot as an image file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot_Series</name>
    <message>
        <location filename="PlotGui.py" line="81"/>
        <source>Configure series</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="84"/>
        <source>Configure series drawing style and label</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_axes</name>
    <message>
        <location filename="TaskPanel.py" line="175"/>
        <source>Configure axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="180"/>
        <source>Active axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="220"/>
        <source>Apply to all axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="225"/>
        <source>Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="230"/>
        <source>X axis position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="235"/>
        <source>Y axis position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="205"/>
        <source>Scales</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="210"/>
        <source>X auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="215"/>
        <source>Y auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="240"/>
        <source>Index of the active axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="245"/>
        <source>Add new axes to the plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="251"/>
        <source>Remove selected axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="257"/>
        <source>Check it to apply transformations to all axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="263"/>
        <source>Left bound of axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="269"/>
        <source>Right bound of axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="275"/>
        <source>Bottom bound of axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="281"/>
        <source>Top bound of axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="287"/>
        <source>Outward offset of X axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="293"/>
        <source>Outward offset of Y axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="299"/>
        <source>X axis scale autoselection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="305"/>
        <source>Y axis scale autoselection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_console</name>
    <message>
        <location filename="Plot.py" line="38"/>
        <source>matplotlib not found, so Plot module can not be loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="InitGui.py" line="54"/>
        <source>matplotlib not found, Plot module will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="42"/>
        <source>Plot document must be selected in order to save it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="365"/>
        <source>Axes 0 can not be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="97"/>
        <source>The grid must be activated on top of a plot document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlotGui.py" line="126"/>
        <source>The legend must be activated on top of a plot document</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_labels</name>
    <message>
        <location filename="TaskPanel.py" line="133"/>
        <source>Set labels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="138"/>
        <source>Active axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="143"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="148"/>
        <source>X label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="153"/>
        <source>Y label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="158"/>
        <source>Index of the active axes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="163"/>
        <source>Title (associated to active axes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="169"/>
        <source>Title font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="175"/>
        <source>X axis title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="181"/>
        <source>X axis title font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="187"/>
        <source>Y axis title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="193"/>
        <source>Y axis title font size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_positions</name>
    <message>
        <location filename="TaskPanel.py" line="121"/>
        <source>Set positions and sizes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="126"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="132"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="138"/>
        <source>List of modificable items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="144"/>
        <source>X item position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="150"/>
        <source>Y item position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="156"/>
        <source>Item size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_save</name>
    <message>
        <location filename="TaskPanel.py" line="128"/>
        <source>Save figure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="133"/>
        <source>Inches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="139"/>
        <source>Dots per Inch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="145"/>
        <source>Output image file path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="151"/>
        <source>Show a file selection dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="157"/>
        <source>X image size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="163"/>
        <source>Y image size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="169"/>
        <source>Dots per point, with size will define output image resolution</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot_series</name>
    <message>
        <location filename="TaskPanel.py" line="154"/>
        <source>No label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="160"/>
        <source>Remove serie</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="196"/>
        <source>Line style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="172"/>
        <source>Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="149"/>
        <source>Configure series</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="178"/>
        <source>List of available series</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="184"/>
        <source>Line title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="202"/>
        <source>Marker style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="208"/>
        <source>Line width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="214"/>
        <source>Marker size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="220"/>
        <source>Line and marker color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="226"/>
        <source>Removes this serie</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="TaskPanel.py" line="190"/>
        <source>If checked serie will not be considered for legend</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
